unit DBUpdate;
{ created by Breyten J. Ernsting (delphi@bje.nu)
May 2000
http://www.bje.nu/
keep this intact if you make other
versions of this
}
interface

{$R *.DCR}

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  db,dbctrls;

type
  TDataSetScrolledEvent = procedure(Sender: TObject;Distance:Integer) of object;
  TRecordChangedEvent = procedure(Sender: TObject;Field:TField) of object;

  TUpdateDatalink = class (TDataLink)
  private
    FOnOnRecordChanged: TRecordChangedEvent;
    FOnOnLayoutChanged: TNotifyEvent;
    FOnOnEditingChanged: TNotifyEvent;
    FOnOnDataSetScrolled: TDataSetScrolledEvent;
    FOnOnDataSetChanged: TNotifyEvent;
    FOnOnCheckBrowseMode: TNotifyEvent;
    FOnOnActiveChanged: TNotifyEvent;
  protected
    procedure ActiveChanged;override;
    procedure CheckBrowseMode;override;
    procedure DataSetChanged;override;
    procedure DataSetScrolled(Distance: Integer);override;
    procedure EditingChanged;override;
    procedure LayoutChanged;override;
    procedure RecordChanged(Field: TField);override;
  public
    constructor Create;
    destructor Destroy;override;
  published
    property OnActiveChanged: TNotifyEvent read FOnOnActiveChanged write FOnOnActiveChanged;
    property OnCheckBrowseMode: TNotifyEvent read FOnOnCheckBrowseMode write FOnOnCheckBrowseMode;
    property OnDataSetChanged: TNotifyEvent read FOnOnDataSetChanged write FOnOnDataSetChanged;
    property OnDataSetScrolled: TDataSetScrolledEvent read FOnOnDataSetScrolled write FOnOnDataSetScrolled;
    property OnEditingChanged: TNotifyEvent read FOnOnEditingChanged write FOnOnEditingChanged;
    property OnLayoutChanged: TNotifyEvent read FOnOnLayoutChanged write FOnOnLayoutChanged;
    property OnRecordChanged: TRecordChangedEvent read FOnOnRecordChanged write FOnOnRecordChanged;
  end; {TUpdateDatalink}

  TUpdateFieldDataLink=class(TFieldDataLink)
  private
    FOnOnEditingChanged : TNotifyEvent;
    FOnOnLayoutChanged : TNotifyEvent;
  protected
    procedure EditingChanged; override;
    procedure LayoutChanged; override;
  public
    constructor Create;
    destructor Destroy; override;
  published
    property OnEditingChanged : TNotifyEvent read FOnOnEditingChanged write FOnOnEditingChanged;
    property OnLayoutChanged : TNotifyEvent read FOnOnLayoutChanged write FOnOnLayoutChanged;
  end;

  TDBUpdate = class(TComponent)
  private
    { Private declarations }
    FDataLink : TUpdateDatalink;
    function GetDataSource : TDataSource;
    procedure SetDataSource(aDataSource:TDataSource);
    function GetActiveChanged : TNotifyEvent;
    procedure SetActiveChanged(anEvent:TNotifyEvent);
    function GetCheckBrowseMode : TNotifyEvent;
    procedure SetCheckBrowseMode(anEvent:TNotifyEvent);
    function GetDataSetChanged : TNotifyEvent;
    procedure SetDataSetChanged(anEvent:TNotifyEvent);
    function GetDataSetScrolled : TDataSetScrolledEvent;
    procedure SetDataSetScrolled(anEvent:TDataSetScrolledEvent);
    function GetEditingChanged : TNotifyEvent;
    procedure SetEditingChanged(anEvent:TNotifyEvent);
    function GetLayoutChanged : TNotifyEvent;
    procedure SetLayoutChanged(anEvent:TNotifyEvent);
    function GetRecordChanged : TRecordChangedEvent;
    procedure SetRecordChanged(anEvent:TRecordChangedEvent);
  protected
    { Protected declarations }
  public
    { Public declarations }
    constructor Create(AOwner:TComponent); override;
    destructor Destroy; override;
  published
    { Published declarations }
    property DataSource : TDataSource read GetDataSource write SetDataSource;
    property OnActiveChanged: TNotifyEvent read GetActiveChanged write SetActiveChanged;
    property OnCheckBrowseMode: TNotifyEvent read GetCheckBrowseMode write SetCheckBrowseMode;
    property OnDataSetChanged: TNotifyEvent read GetDataSetChanged write SetDataSetChanged;
    property OnDataSetScrolled: TDataSetScrolledEvent read GetDataSetScrolled write SetDataSetScrolled;
    property OnEditingChanged: TNotifyEvent read GetEditingChanged write SetEditingChanged;
    property OnLayoutChanged: TNotifyEvent read GetLayoutChanged write SetLayoutChanged;
    property OnRecordChanged: TRecordChangedEvent read GetRecordChanged write SetRecordChanged;
  end;

  TDBFieldUpdate=class(TComponent)
  private
    FDataLink : TUpdateFieldDataLink;
    function GetDataField: string;                   { returns the name of the data field }
    function GetDataSource: TDataSource;           { returns reference to the data source }
    procedure SetDataField(const Value: string);             { assigns name of data field }
    procedure SetDataSource(Value: TDataSource);
    function GetActiveChange : TNotifyEvent;
    procedure SetActiveChange(anEvent:TNotifyEvent);
    function GetDataChange : TNotifyEvent;
    procedure SetDataChange(anEvent:TNotifyEvent);
    function GetEditingChange : TNotifyEvent;
    procedure SetEditingChange(anEvent:TNotifyEvent);
    function GetUpdateData : TNotifyEvent;
    procedure SetUpdateData(anEvent:TNotifyEvent);
    function GetEditingChanged : TNotifyEvent;
    procedure SetEditingChanged(anEvent:TNotifyEvent);
    function GetLayoutChanged : TNotifyEvent;
    procedure SetLayoutChanged(anEvent:TNotifyEvent);
  public
    constructor Create(AOwner:TComponent); override;
    destructor Destroy; override;
  published
    property DataSource : TDataSource read GetDataSource write SetDataSource;
    property DataField : String read GetDataField write SetDataField;
    property OnActiveChange : TNotifyEvent read GetActiveChange write SetActiveChange;
    property OnDataChange : TNotifyEvent read GetDataChange write SetDataChange;
    property OnEditingChange : TNotifyEvent read GetEditingChange write SetEditingChange;
    property OnUpdateData : TNotifyEvent read GetUpdateData write SetUpdateData;
    property OnEditingChanged : TNotifyEvent read GetEditingChanged write SetEditingChanged;
    property OnLayoutChanged : TNotifyEvent read GetLayoutChanged write SetLayoutChanged;
  end;

procedure Register;

implementation

//------------------------------------------------------------------
//                       TUpdateDatalink
//------------------------------------------------------------------

{Private methods for TUpdateDatalink}
{Protected methods for TUpdateDatalink}
procedure TUpdateDatalink.ActiveChanged;
begin
   if Assigned(FOnOnActiveChanged) then
      FOnOnActiveChanged(Self);
   inherited ActiveChanged;
end; {ActiveChanged}

procedure TUpdateDatalink.CheckBrowseMode;
begin
   if Assigned(FOnOnCheckBrowseMode) then
      FOnOnCheckBrowseMode(Self);
   inherited CheckBrowseMode;
end; {CheckBrowseMode}

procedure TUpdateDatalink.DataSetChanged;
begin
   if Assigned(FOnOnDataSetChanged) then
      FOnOnDataSetChanged(Self);
   inherited DataSetChanged;
end; {DataSetChanged}

procedure TUpdateDatalink.DataSetScrolled(Distance: Integer);
begin
   if Assigned(FOnOnDataSetScrolled) then
      FOnOnDataSetScrolled(Self,Distance);
   inherited DataSetScrolled(Distance);
end; {DataSetScrolled}

procedure TUpdateDatalink.EditingChanged;
begin
   if Assigned(FOnOnEditingChanged) then
      FOnOnEditingChanged(Self);
   inherited EditingChanged;
end; {EditingChanged}

procedure TUpdateDatalink.LayoutChanged;
begin
   if Assigned(FOnOnLayoutChanged) then
      FOnOnLayoutChanged(Self);
   inherited LayoutChanged;
end; {LayoutChanged}

procedure TUpdateDatalink.RecordChanged(Field: TField);
begin
   if Assigned(FOnOnRecordChanged) then
      FOnOnRecordChanged(Self,Field);
   inherited RecordChanged(Field);
end; {RecordChanged}

{Public methods for TUpdateDatalink}
constructor TUpdateDatalink.Create;
begin
   inherited Create;
end; {Create}

destructor TUpdateDatalink.Destroy;
begin
   inherited Destroy;
end; {Destroy}

{Published methods for TUpdateDatalink}

{ TUpdateFieldDataLink }
constructor TUpdateFieldDataLink.Create;
begin
   inherited Create;
end;

destructor TUpdateFieldDataLink.Destroy;
begin
   inherited Destroy;
end;

procedure TUpdateFieldDataLink.EditingChanged;
begin
   if Assigned(FOnOnEditingChanged) then
      FOnOnEditingChanged(Self);
   inherited EditingChanged;
end;

procedure TUpdateFieldDataLink.LayoutChanged;
begin
   if Assigned(FOnOnLayoutChanged) then
      FOnOnLayoutChanged(Self);
   inherited LayoutChanged;
end;

{ TDBUpdate}
constructor TDBUpdate.Create;
begin
   inherited Create(AOwner);
   FDataLink := TUpdateDatalink.Create;
end;

destructor TDBUpdate.Destroy;
begin
  FDataLink.Free;
  inherited Destroy;
end;

function TDBUpdate.GetDataSource;
begin
   Result := FDataLink.DataSource;
end;

procedure TDBUpdate.SetDataSource;
begin
   FDataLink.DataSource := aDataSource;
end;

function TDBUpdate.GetActiveChanged;
begin
   Result := FDataLink.OnActiveChanged;
end;

procedure TDBUpdate.SetActiveChanged;
begin
   FDataLink.OnActiveChanged := anEvent;
end;

function TDBUpdate.GetCheckBrowseMode;
begin
   Result := FDataLink.OnCheckBrowseMode;
end;

procedure TDBUpdate.SetCheckBrowseMode;
begin
   FDataLink.OnCheckBrowseMode := anEvent;
end;

function TDBUpdate.GetDataSetChanged;
begin
   Result := FDataLink.FOnOnDataSetChanged;
end;

procedure TDBUpdate.SetDataSetChanged;
begin
   FDataLink.OnDataSetChanged := anEvent;
end;

function TDBUpdate.GetDataSetScrolled;
begin
   Result := FDataLink.OnDataSetScrolled;
end;

procedure TDBUpdate.SetDataSetScrolled;
begin
   FDataLink.OnDataSetScrolled := anEvent;
end;

function TDBUpdate.GetEditingChanged;
begin
   Result := FDataLink.OnEditingChanged;
end;

procedure TDBUpdate.SetEditingChanged;
begin
   FDataLink.OnEditingChanged := anEvent;
end;

function TDBUpdate.GetLayoutChanged;
begin
   Result := FDataLink.OnLayoutChanged;
end;

procedure TDBUpdate.SetLayoutChanged;
begin
   FDataLink.OnLayoutChanged := anEvent;
end;

function TDBUpdate.GetRecordChanged;
begin
   Result := FDataLink.OnRecordChanged;
end;

procedure TDBUpdate.SetRecordChanged;
begin
   FDataLink.OnRecordChanged := anEvent;
end;

{TDBFieldUpdate}
constructor TDBFieldUpdate.Create;
begin
   inherited Create(AOwner);
   FDataLink := TUpdateFieldDataLink.Create;
   FDataLink.Control := Self;
end;

destructor TDBFieldUpdate.Destroy;
begin
   FDataLink.Free;
   inherited Destroy;
end;

function TDBFieldUpdate.GetDataField;
begin
   Result := FDataLink.FieldName;
end;

procedure TDBFieldUpdate.SetDataField;
begin
   FDataLink.FieldName := Value;
end;

function TDBFieldUpdate.GetDataSource;
begin
   Result := FDataLink.DataSource;
end;

procedure TDBFieldUpdate.SetDataSource;
begin
   FDataLink.DataSource := Value;
end;

function TDBFieldUpdate.GetActiveChange;
begin
   Result := FDataLink.OnActiveChange;
end;

procedure TDBFieldUpdate.SetActiveChange;
begin
   FDataLink.OnActiveChange := anEvent;
end;

function TDBFieldUpdate.GetDataChange;
begin
   Result := FDataLink.OnDataChange;
end;

procedure TDBFieldUpdate.SetDataChange;
begin
   FDataLink.OnDataChange := anEvent;
end;

function TDBFieldUpdate.GetEditingChange;
begin
  Result := FDataLink.OnEditingChange;
end;

procedure TDBFieldUpdate.SetEditingChange;
begin
   FDataLink.OnEditingChange := anEvent;
end;

function TDBFieldUpdate.GetEditingChanged;
begin
   Result := FDataLink.OnEditingChanged;
end;

procedure TDBFieldUpdate.SetEditingChanged;
begin
   FDataLink.OnEditingChanged := anEvent;
end;

function TDBFieldUpdate.GetLayoutChanged;
begin
   Result := FDataLink.OnLayoutChanged;
end;

procedure TDBFieldUpdate.SetLayoutChanged;
begin
   FDataLink.OnLayoutChanged := anEvent;
end;

function TDBFieldUpdate.GetUpdateData;
begin
   Result := FDataLink.OnUpdateData;
end;

procedure TDBFieldUpdate.SetUpdateData;
begin
   FDataLink.OnUpdateData := anEvent;
end;

procedure Register;
begin
  RegisterComponents('GPF', [TDBUpdate,TDBFieldUpdate]);
end;

end.
